package jwebstack.util;

import org.mortbay.jetty.Connector;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.nio.SelectChannelConnector;
import org.mortbay.jetty.webapp.WebAppContext;

public class JettyServer {
	private static final String WAR_PATH = "src/main/webapp";

	private static final String CONTEXT_PATH = "/";

	private static JettyServer jettyServer;

	public static final String HOST = "127.0.0.1";

	public static final int PORT = 9090;

	public static final String getUrl() {
		return "http://" + HOST + ":" + PORT + CONTEXT_PATH;
	}

	public static boolean isServerRunning() {
		return jettyServer != null && jettyServer.isRunning();
	}

	public static synchronized void startServer() throws Exception {
		if (jettyServer == null) {
			jettyServer = new JettyServer();
		}

		jettyServer.start();
	}

	public static synchronized void stopServer() throws Exception {
		if (jettyServer != null) {
			jettyServer.stop();
		}
	}

	private Server server;

	private JettyServer() {
		System.setProperty("org.mortbay.log.class", JettyLogger.class.getCanonicalName());
		server = new Server();
	}

	public void start() throws Exception {
		setConnectors();
		setWebAppContext();
		server.setStopAtShutdown(true);
		server.start();
	}

	public void stop() throws Exception {
		server.stop();
	}

	public boolean isRunning() {
		return server.isRunning();
	}

	private void setConnectors() {
		Connector connector = new SelectChannelConnector();
		connector.setPort(PORT);
		connector.setHost(HOST);
		server.setConnectors(new Connector[] { connector });
	}

	private void setWebAppContext() {
		WebAppContext wac = new WebAppContext();
		wac.setContextPath(CONTEXT_PATH);
		wac.setWar(WAR_PATH);
		server.setHandler(wac);
	}
}
